@@ -510,14 +510,41 @@ class Session:
     # if p.has_key('weber'):
     #   if p['weber'] is True:
     if "weber=" in str(params):
-      redirect_url = hub_url
-      idx = redirect_url.find('://')
-      if idx != -1:
-        redirect_url = redirect_url[idx+3:]
-      idx = redirect_url.find('/')
-      if idx != -1:
-        redirect_url = redirect_url[0:idx]
-      redirect_url = "https://proxy." + redirect_url
+      import os
+      # construct redirect_url from /etc/mw-proxy/front-proxy.conf
+      FRONT_PROXY_CONFIG_FILE = '/etc/mw-proxy/front-proxy.conf'
+      # FRONT_LISTEN_PORT = 443
+      # FRONT_LISTEN_SSL = True
+      # FRONT_LISTEN_HOST = ''
+      proxy_vars = {}
+      if os.path.isfile(FRONT_PROXY_CONFIG_FILE):
+	# read values into proxy_vars, otherwise "global name 'FRONT_...' is not defined"
+	# because they go into locals but can't access them
+        execfile(FRONT_PROXY_CONFIG_FILE, proxy_vars)
+      else:
+	log("front proxy config file is not readable")
+      # log("front listen host is '%s'" % str(proxy_vars['FRONT_LISTEN_HOST']))
+      if proxy_vars['FRONT_LISTEN_SSL']:
+        prefix = "https://"
+      else:
+	prefix = "http://"
+      if proxy_vars['FRONT_LISTEN_HOST'] == '':
+	# guess it from hostname of hub_url and prepend https://proxy.
+        host = hub_url
+        idx = host.find('://')
+        if idx != -1:
+          host = host[idx+3:]
+        idx = host.find('/')
+        if idx != -1:
+          host = host[0:idx]
+        prefix = prefix + "proxy." + host
+      else:
+	prefix = prefix + proxy_vars['FRONT_LISTEN_HOST']
+      if proxy_vars['FRONT_LISTEN_PORT'] == 443:
+        redirect_url = prefix
+      else:
+        redirect_url = prefix + ":" + proxy_vars['FRONT_LISTEN_PORT']
+      log("redirect_url is '%s'" % str(redirect_url ))
       row = db.getrow(
         """SELECT fileperm.cookie,display.dispnum,fileperm.fileuser
            FROM fileperm,display
@@ -686,6 +713,8 @@ class Session:
         time.sleep(get_stats_delay)
       else:
         got_them = True
+        os.chmod(self.K["LOG_PATH"] + "/%d.out" % self.sessnum, 0640)
+        os.chmod(self.K["LOG_PATH"] + "/%d.err" % self.sessnum, 0640)
 
     # Call maxwell_service to "purgeoutputs"
     # this deletes the files we just scped.
